function [z,x,ele_cc,range_cc]=curvature_correction(range,ele_ec)


% -------------------------------------------------------------------------
%*Function* curvature_correction.m
% @version sacr 1.1

% *SRC_FILE*
% sacrm/curvature_correction.m
%
%
%  
%
%
%  
%%%%%%%%%%%%% DESCRIPTION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function corrects range and elevation for Earth's curvature and
% calculates vertical and horizontal distances away from the radar.
%%%%%%%%%%%%% INPUTS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% range : range (m) [number of range gates,1]
% ele   : elevation (degrees) [number of elevations,1]
%%%%%%%%%%%%% OUTPUS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% z        : distance from the ground up (m) 
%            [number of elevation,number of range gates]
% x        : distance away from the radar (m)
%            [number of elevation,number of range gates]
% ele_cc   : elevation corrected for Earth's curvature (degrees)
%            [number of elevation,number of range gates]
% range_cc : range corrected for Earth's curvature (m)
%            [number of elevation,number of range gates]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%  This program  contains the subroutines needed for procesing raw sacr data
%
%
%  Copyright (C) 2014 McGill Clouds Research Group (http://www.clouds.mcgill.ca/)
%  Contact email address: pavlos.kollias@mcgill.ca, aleksandra.tatarevic@mcgill.ca,
%  iengjo@meteo.mcgill.ca
%
%  This source code is free software: you can redistribute it and/or modify
%  it under the terms of the GNU Lesser General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU Lesser General Public License for more details.
%
%  You should have received a copy of the GNU Lesser General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% ----------------------------------------------------------------------------
 
pr= 4*6357*1000/3; % 4/3 of Earth's radius

z = NaN(length(range),length(ele_ec));
x = NaN(length(range),length(ele_ec));

for e=1:length(ele_ec)
    z(:,e)=(((range(:).^2)+(pr.^2)+(2*range(:)*pr*sin(ele_ec(e)*pi/180))).^.5)-pr;
end

for e=1:length(ele_ec)
    if ele_ec(e)>90
    x(:,e)=pr*asin(range(:)*cos((360-ele_ec(e))*pi/180)./(pr+z(:,e)));
    else
    x(:,e)=pr*asin(range(:)*cos(ele_ec(e)*pi/180)./(pr+z(:,e)));
    end    
end

ele_cc = atan(z./x)*180/pi;
  
ele_cc(ele_cc<0)=ele_cc(ele_cc<0)+180;
  
range_cc = (x.^2+z.^2).^.5;
 

end

