function  [dbz_ec,ldr_ec,velo_ec,sw_ec,dbz_rc_ec,ele_ec,time_ec,azimuth_ec,snr_ec] = elevation_correction(ele_raw,dbz_raw,velo_raw,sw_raw,dbz_rc,ldr_raw,time_raw,snr_raw,azimuth_raw,bw);

%*Function* elevation_correction.m
% @version sacr 1.1

% *SRC_FILE*
% sacrm/elevation_correction.m
%
 
%
%   
%%%%%%%%%%%%%%%%%%%%%%%% DESCRIPTION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
% This functions corrects scans starting at 180 degrees  
% degrees   and bring them to the convention 0 degrees azimuth to 180
% degrees  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%% INPUTS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ele_raw        : elevation angle from raw data (degrees)
%                  [number of range gates,number of elevations]
% dbz_raw        : reflectivity from raw data (dBZ)
%                  [number of range gates,number of elevations]
% velo_raw       : doppler velocity from raw data (m/s)
%                  [number of range gates,number of elevations]
% sw_raw         : spectrum width from raw data (m/s)
%                  [number of range gates,number of elevations]
% dbz_rc         : reflectivity from raw data corrected for range
%                  attenuation (dBZ)
%                  [number of range gates,number of elevations]
% ldr_raw        : depolarization ration from raw data
%                  [number of range gates,number of elevations]
% time_raw       : time from raw data (s)
%                  [number of elevations,1]
% snr_raw        : signal to noise ratio from raw data
%                  [number of range gates,number of elevations]
% azimuth_raw    : azimuth angle from raw data (degrees from true North)
%                  [number of elevations,1]
%%%%%%%%%%%%%%%%%%%%%%%% OUTPUTS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% same variables ajusted to convention
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  This program  contains the subroutines needed for procesing raw sacr data
%
%
%  Copyright (C) 2014 McGill Clouds Research Group (http://www.clouds.mcgill.ca/)
%  Contact email address: pavlos.kollias@mcgill.ca, aleksandra.tatarevic@mcgill.ca,
%  iengjo@meteo.mcgill.ca
%
%  This source code is free software: you can redistribute it and/or modify
%  it under the terms of the GNU Lesser General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU Lesser General Public License for more details.
%
%  You should have received a copy of the GNU Lesser General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% ----------------------------------------------------------------------------


size_variables = size(dbz_raw);

if (nanmean(ele_raw(1:10))>nanmean(ele_raw(length(ele_raw)-10:length(ele_raw))))  % Check if the elevations are flipped
    
ele     = flipud(ele_raw); 
dbz     = NaN(size_variables);
ldr     = NaN(size_variables);
velo    = NaN(size_variables);
width   = NaN(size_variables);
dbzhc   = NaN(size_variables);
snr     = NaN(size_variables);
azimth  = flipud(azimuth_raw);
time    =flipud(time_raw);
        
for e_1 =1:length(ele)        
dbz(:,e_1)    = dbz_raw(:,length(ele)+1-e_1);
velo(:,e_1)   = velo_raw(:,length(ele)+1-e_1);
width(:,e_1)  = sw_raw(:,length(ele)+1-e_1);
dbzhc(:,e_1)  = dbz_rc(:,length(ele)+1-e_1);
ldr(:,e_1)    = ldr_raw(:,length(ele)+1-e_1);
snr(:,e_1)    = snr_raw(:,length(ele)+1-e_1);
end
   

lop1=find(abs(diff(ele))>bw/16 );

ele_ec           = ele(lop1);
dbz_ec           = dbz(:,lop1);
velo_ec          = velo(:,lop1);
sw_ec            = width(:,lop1);
dbz_rc_ec        = dbzhc(:,lop1);
ldr_ec           = ldr(:,lop1); 
time_ec           = time(lop1);
azimuth_ec       = azimth(lop1);
snr_ec           = snr(:,lop1);

else 

 


lop1=find(abs(diff(ele_raw))>bw/16);
 
ele_ec           = ele_raw(lop1);
dbz_ec           = dbz_raw(:,lop1);
velo_ec          = velo_raw(:,lop1);
sw_ec            = sw_raw(:,lop1);
dbz_rc_ec        = dbz_rc(:,lop1);
ldr_ec           = ldr_raw(:,lop1); 
time_ec          = time_raw(lop1);
azimuth_ec       = azimuth_raw(lop1);
snr_ec           = snr_raw(:,lop1);
 
end  % END if (nanmean(ele_raw(1:10))>nanmean(ele_raw(length(ele_raw)-10:length(ele_raw))))
  

 
end
