%%%%%%%%%
% *Function* : parameters.m
% @version sacrm 1.1
%
% *SRC_FILE*
% /sacrm/parameters.m
%
%
% *LAST CHANGES*
%
%
% *DESCRIPTION*
%
% This package contains 14 Matlab codes in total, with this package%
% the user will be able to process data from any radar , any mode from%
% the Atmospheric Radiation Measurement (ARM) program.
% It produces the data quality control and post-processing of the calibrated SACR measurements.
% code SACRM v1 (our code that is also available to public) is written in
% FORTRAN...CHECK WITH ALEKS
%
%%%%%%              INPUT           %%%%%%
% the input parameters are specified in this code.
%  
%   radar=''                %KaSACR, WbSACR ,XaSACR   this specifies what radar data to be processed. [string]
%   location=''             %sgp,grw,mag,nsa,pvc,twp or any other arm site.  [string]     
%   date= ''                %date to be processed 'yyyymmdd'. [string]
%   mode= ''                %vptmo,blrhi,cwrhi,ppimo,hsrhi,awrhi  mode. [string]
%   path_functions=''       %%% where all functions are. [string] 

%   path_raw_data=[''] %%% directory path where raw data is. [string]  
 
%   path_processed_data=[''] %%% directory path where processed data will
%   be stored. [string]

%   path_sounding_data=[''] %%%  directory path where soundings files are. [string]

%   path_ceilo_data=[''] %%% directory path where ceilometer data is. [string]

 
% 
%
% *OUTPUT*
%
% A set of  ncdfs outputs is generated and saved at the directory specified
% by parameter:  path_processed_data
% 
%
%
%  Copyright (C) 2014 McGill Clouds Research Group (http://www.clouds.mcgill.ca/)
%  Contact email address: pavlos.kollias@mcgill.ca, aleksandra.tatarevic@mcgill.ca,iengjo@meteo.mcgill.ca
%
%  This source code is free software: you can redistribute it and/or modify
%  it under the terms of the GNU Lesser General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU Lesser General Public License for more details.
%
%  You should have received a copy of the GNU Lesser General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%


clear all

radar='KaSACR'          %KaSACR, WbSACR ,XaSACR   this specifies what radar data to be processed. 
location='sgp'          %sgp,grw,mag,nsa,pvc,twp or any other arm site.      
date= '20120320'        %date to be processed 
mode='cwrhi'            %vptmo,blrhi,cwrhi,ppimo,hsrhi,awrhi   scanning mode.

%%%%%%%                               %%%%%%%
%%%%%%% Define data paths accordingly %%%%%%%
%%%%%%%                               %%%%%%%  

path_noise_clear_sky='/Users/iengjo/trabajo/sacrm_v1_1/sacrm_aux/' %%% where the data for clear sky is %%used during masking %%%
                                                                      %%% a climotological file is provided for the arm sites   %%%
                                                                      %%% used so far adapt accordingly                         %%%                                         
                                                          
path_functions='/Users/iengjo/trabajo/sacrm_v1_1/'       %%% where all functions are %%%

path_raw_data=['/Users/iengjo/storage/common_data/',upper(location),'/raw_data/',radar,'/',mode,'_data/'] %%% where raw data is %%%
 
path_processed_data=['/Users/iengjo/storage/common_data/',upper(location),'/processed_data/',radar,'/',mode,'_data/',date,'/'] %%% where processed 
                                                                                                                               %%% data will be stored
path_mergedsounding_data=['/Users/iengjo/storage/common_data/',upper(location),'/raw_data/mergedsonde_data/'] %%% where merged soundings files are %%%
path_sounding_data=['/Users/iengjo/storage/common_data/',upper(location),'/raw_data/sounding_data/'] %%% where soundings files are %%%

path_ceilo_data=['/Users/iengjo/storage/common_data/',upper(location),'/raw_data/ceilo_data/'] %%% where ceilometer data is %%%

 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
mkdir (path_processed_data);                                    %%%create a directory where the processed data will be saved%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%% If using parallel mode, define the path where the functions are allocated %%%%%%%%%%

path(path,path_functions)  
cd(path_functions)
 
matlabpool open 2 % open number of workers for parallel processing 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%% First level processing %%%%%%%%%%%%%%%%%%%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Separates into individual scans, first masking using snr values, saves netcdf
%files with individual scans 
  
[status]=read_raw_data_int(path_noise_clear_sky,path_functions,path_raw_data,path_processed_data,radar,location,date,mode)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
%%%%%%%%%%%%%%%%%%% Second level processing %%%%%%%%%%%%%%%%%%%%%%

%%%%%% Use this codes ONLY IF ceilometer data and sounding data are
%%%%%% available.

%Uses ceilometer data for insects removal.
%Sounding to correct aliasing.
%Second trip echoes removal.
%Second masking using a 5x5 boxcar filter.
 cd(path_functions)
 [status]=read_flprocessed_data_complete_sl_processing_int(path_processed_data,path_functions,path_sounding_data,path_mergedsounding_data,...
                                                                   path_ceilo_data,radar,location,date,mode)

matlabpool close %%% close workers for parallel processing

clear all       
