function[stat]=put_new_var_into_netcdf(ncid,DBZ_cor,Up_90,Up_az,Up_az_el,VD_unfolded_final,wind_speed,wind_dir,number_alias,tdry,height,VD_unf_flag,percentage_VD_unf_flag,wspd,wdir,...
                               dbz,velo,sw,ldr,dbz_fact,dbz_offset,velo_fact,velo_offset,sw_fact,sw_offset,ldr_fact,ldr_offset,dt_sounding_scan,sounding_file,ceilo_file);
                           
 
% -------------------------------------------------------------------------
%*Function* put_new_var_into_netcdf.m
% @version sacr 1.1

% *SRC_FILE*
% sacrm/put_new_var_into_netcdf.m
%
%
%                            
                           

%  
%%%%%%%%%%%%%%%%%%%% DESCRIPTION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function writes netcdf files for each scan of each file
% individually. The netcdf files outputed contain variables with the
% data corrected to the elevation convention and masked and  variables 
% with processed data such as sounding data, dealiazed doppler
% velocity, reflectivity corrected for attenuation....
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%  This program  contains the subroutines needed for procesing raw sacr data
%
%
%  Copyright (C) 2014 McGill Clouds Research Group (http://www.clouds.mcgill.ca/)
%  Contact email address: pavlos.kollias@mcgill.ca, aleksandra.tatarevic@mcgill.ca,
%  iengjo@meteo.mcgill.ca
%
%  This source code is free software: you can redistribute it and/or modify
%  it under the terms of the GNU Lesser General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU Lesser General Public License for more details.
%
%  You should have received a copy of the GNU Lesser General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% ----------------------------------------------------------------------------

    souding_size=length(height);
    [dimname1] = netcdf.inqDim(ncid,0);
    dimid1=netcdf.inqDimID(ncid,dimname1); %get maxCells dimension
    [dimname2] = netcdf.inqDim(ncid,1);
    dimid2=netcdf.inqDimID(ncid,dimname2);%get time dimension
    [dimname3] = netcdf.inqDim(ncid,2);
    dimid3=netcdf.inqDimID(ncid,dimname3); %get numone dimension
    attname1 = netcdf.inqAttName(ncid,netcdf.getConstant('NC_GLOBAL'),8);
    attname2 = netcdf.inqAttName(ncid,netcdf.getConstant('NC_GLOBAL'),9);
   
netcdf.reDef(ncid);

sondeID           = netcdf.defDim(ncid,'sounde',souding_size); 
 


DBZ_corid                  = netcdf.defVar(ncid,'DBZ_cor','nc_int',[dimid1,dimid2]);
Up_90id                    = netcdf.defVar(ncid,'Up_90','nc_int',[dimid1,dimid2]);
Up_azid                    = netcdf.defVar(ncid,'Up_az','nc_int',[dimid1,dimid2]);
Up_az_elid                 = netcdf.defVar(ncid,'Up_az_el','nc_int',[dimid1,dimid2]);
VD_unfoldedid              = netcdf.defVar(ncid,'VD_unfolded','nc_int',[dimid1,dimid2]);
wfid                       = netcdf.defVar(ncid,'wf','float',[dimid1,dimid2]);
wdid                       = netcdf.defVar(ncid,'wd','float',[dimid1,dimid2]);
aliasnid                   = netcdf.defVar(ncid,'aliasn','nc_int',[dimid1,dimid2]);

sonde_temperatureid = netcdf.defVar(ncid,'Temperature','float',sondeID);
sonde_heightid      = netcdf.defVar(ncid,'height','float',sondeID);
VD_unf_flagid       = netcdf.defVar(ncid,'VD_unf_flag','nc_int',dimid2); 
percentage_flagid   = netcdf.defVar(ncid,'percentage_flag','nc_int',dimid3); 
sonde_wspdid        = netcdf.defVar(ncid,'wspd_sounding','float',sondeID);
sonde_wdirid        = netcdf.defVar(ncid,'wdir_sounding','float',sondeID);
dt_sounding_scanid  = netcdf.defVar(ncid,'dt_sounding_scan','nc_int',dimid3); 


netcdf.putAtt(ncid,netcdf.getConstant('nc_global'),attname1,sounding_file);
netcdf.putAtt(ncid,netcdf.getConstant('nc_global'),attname2,ceilo_file);

netcdf.putAtt(ncid,24,'units','dBZ');
netcdf.putAtt(ncid,24,'scale_factor',dbz_fact);
netcdf.putAtt(ncid,24,'add_offset',dbz_offset);
netcdf.putAtt(ncid,24,'comment', 'To unpack field, multiply values by the scale_factor attribute, then add the add_offset attribute.');
netcdf.putAtt(ncid,24,'long_name','DBZ corrected');
netcdf.putAtt(ncid,24,'missing_value','-999.000');

netcdf.putAtt(ncid,25,'units','m/s');
netcdf.putAtt(ncid,25,'scale_factor',velo_fact);
netcdf.putAtt(ncid,25,'add_offset',velo_offset);
netcdf.putAtt(ncid,25,'comment', 'To unpack field, multiply values by the scale_factor attribute, then add the add_offset attribute.');
netcdf.putAtt(ncid,25,'long_name','Projected velocity across the radar plane using sounding data');
netcdf.putAtt(ncid,25,'missing_value','-999.000');

netcdf.putAtt(ncid,26,'units','m/s');
netcdf.putAtt(ncid,26,'scale_factor',velo_fact);
netcdf.putAtt(ncid,26,'add_offset',velo_offset);
netcdf.putAtt(ncid,26,'comment', 'To unpack field, multiply values by the scale_factor attribute, then add the add_offset attribute.');
netcdf.putAtt(ncid,26,'long_name','Projected velocity across the radar plane using sounding data');
netcdf.putAtt(ncid,26,'missing_value','-999.000');

netcdf.putAtt(ncid,27,'units','m/s');
netcdf.putAtt(ncid,27,'scale_factor',velo_fact);
netcdf.putAtt(ncid,27,'add_offset',velo_offset);
netcdf.putAtt(ncid,27,'comment', 'To unpack field, multiply values by the scale_factor attribute, then add the add_offset attribute.');
netcdf.putAtt(ncid,27,'long_name','Projected velocity towards/away from the radar using sounding data');
netcdf.putAtt(ncid,27,'missing_value','-999.000');

netcdf.putAtt(ncid,28,'units','m/s');
netcdf.putAtt(ncid,28,'scale_factor',velo_fact);
netcdf.putAtt(ncid,28,'add_offset',velo_offset);
netcdf.putAtt(ncid,28,'comment', 'To unpack field, multiply values by the scale_factor attribute, then add the add_offset attribute.');
netcdf.putAtt(ncid,28,'long_name','Doppler velocity unfolded');
netcdf.putAtt(ncid,28,'missing_value','-999.000');

netcdf.putAtt(ncid,29,'units','m/s');
netcdf.putAtt(ncid,29,'long_name','wind force');
netcdf.putAtt(ncid,29,'missing_value','-999.000');

netcdf.putAtt(ncid,30,'units','degrees');
netcdf.putAtt(ncid,30,'long_name','wind direction');
netcdf.putAtt(ncid,30,'missing_value','-999.000');

netcdf.putAtt(ncid,31,'units','none');
netcdf.putAtt(ncid,31,'long_name','number of aliasing');
netcdf.putAtt(ncid,31,'missing_value','-999.000');

netcdf.putAtt(ncid,32,'units','Celsius');
netcdf.putAtt(ncid,32,'long_name','temperature from sounding');
netcdf.putAtt(ncid,32,'missing_value','-999.000');


netcdf.putAtt(ncid,33,'units','km');
netcdf.putAtt(ncid,33,'long_name','height from sounding');
netcdf.putAtt(ncid,33,'missing_value','-999.000');


netcdf.putAtt(ncid,34,'units','1=bad ray');
netcdf.putAtt(ncid,34,'long_name','de-aliasing quality control');


netcdf.putAtt(ncid,35,'units','percentage');
netcdf.putAtt(ncid,35,'long_name','percentage of rays with bad valules of unfolded velocities');
 


netcdf.putAtt(ncid,36,'units','m/s');
netcdf.putAtt(ncid,36,'long_name','wspd from sounding');


netcdf.putAtt(ncid,37,'units','degrees from the East');
netcdf.putAtt(ncid,37,'long_name',' wind direction from sounding');


netcdf.putAtt(ncid,38,'units','s');
netcdf.putAtt(ncid,38,'long_name','time difference between scan and closest sounding');
netcdf.putAtt(ncid,38,'missing_value','-999.000');

netcdf.endDef(ncid);  

%%%
netcdf.putVar(ncid,14,int32((dbz'-dbz_offset)/dbz_fact));
netcdf.putVar(ncid,15,int32((velo'-velo_offset)/velo_fact)); 
netcdf.putVar(ncid,16,int32((sw'-sw_offset)/sw_fact)); 
netcdf.putVar(ncid,22,int32((ldr'-ldr_offset)/ldr_fact)); 

%%%
netcdf.putVar(ncid,24,int32((DBZ_cor'-dbz_offset)/dbz_fact));

netcdf.putVar(ncid,25,int32((Up_90'-velo_offset)/velo_fact)); 
netcdf.putVar(ncid,26,int32((Up_az'-velo_offset)/velo_fact));
netcdf.putVar(ncid,27,int32((Up_az_el'-velo_offset)/velo_fact));
netcdf.putVar(ncid,28,int32((VD_unfolded_final'-velo_offset)/velo_fact)); 
netcdf.putVar(ncid,29,wind_speed');
netcdf.putVar(ncid,30,wind_dir'); 
netcdf.putVar(ncid,31,number_alias');
netcdf.putVar(ncid,32,tdry);
netcdf.putVar(ncid,33,height/1000);
netcdf.putVar(ncid,34,int32(VD_unf_flag));
netcdf.putVar(ncid,35,int32(percentage_VD_unf_flag));
netcdf.putVar(ncid,36,wspd);
netcdf.putVar(ncid,37,wdir);
netcdf.putVar(ncid,38,int32(dt_sounding_scan));
  
stat='complete' ;
end

 
