function [status]=read_flprocessed_data_complete_sl_processing_int(path_processed_data,path_functions,path_sounding_data,path_mergedsounding_data,...
                                                                   path_ceilo_data,radar,location,date,mode)
%*Function* read_flprocessed_data_complete_sl_processing_int.m
% @version sacr 1.1

% *SRC_FILE*
% sacrm/read_flprocessed_data_complete_sl_processing_int.m

%changes:This versions takes advantage of merged sounding data products. If merged sounding data is present,
%this code uses it. If not, it uses regular sounding. A new variable is
%added to the final netcdf file: dt_sounding_scan whis is the time
%difference between scan and closest sounding.
%new function is introduced :put_new_var_into_netcdf.m : Adds all new
%processed variables to the existing netcdf file.
%
%  
%
%
%   



%%%%%%%%%%%%%%%%%%%% DESCRIPTION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function reads first level processed data one scan at the time for 
% each file of the chosen radar, date, location and mode. It removes % extremes values.

 
% This function calls: read_sounding.m  
% This function calls: gas_attenuation_rose98.m
% This function calls: dealiasing.m 
% This function calls: sacr_masking_echo.m
% This function calls: put_new_var_into_netcdf.m
% This function calls: readnetcdf.m
% This function calls: sacr_masking_iter_2.m
% This function calls: put_new_var_into_netcdf.m
 
% This function then fills the processed netcdf file with the new variables
% generated
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%% INPUTS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% path_processed_data  : name of the directory where the processed data 
%                        netcdf file is located  [string]
% path_functions       : name of the directory where where the functions 
%                        are stored [string]
% path_sounding_data   : name of the directory where the raw sounding data 
%                        is located [string]
% radar                : instrument name [string]
% location             : site [string]
% date                 : date in format YYYMMDD [string]
% mode                 : scan strategy [string]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%   OUTPUTS %%%%%%%

% same netcdf files with added corrected variables %
% For the complete list of output variables refer to our website:
% www.clouds.mcgill.ca/blba bla bal
%  This program  contains the subroutines needed for procesing raw sacr data
%
%
%  Copyright (C) 2014 McGill Clouds Research Group (http://www.clouds.mcgill.ca/)
%  Contact email address: pavlos.kollias@mcgill.ca, aleksandra.tatarevic@mcgill.ca,
%  iengjo@meteo.mcgill.ca
%
%  This source code is free software: you can redistribute it and/or modify
%  it under the terms of the GNU Lesser General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU Lesser General Public License for more details.
%
%  You should have received a copy of the GNU Lesser General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% ----------------------------------------------------------------------------

cd (path_processed_data);
 
a=dir('*.nc');
kkk = length(a);
lastfile=a(kkk).name;

 for file=1:kkk
        
         
    
warning off
       
%%%%%%%%%%%%%%%%% Read processed data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% All processed data variable have been corrected to the elevation
% convention. However from this point on the _ec name will be omited
   
data1 =[a(file).name] ;permission='NC_WRITE'; 

fname=strcat([path_processed_data,data1]);

display(data1)
 
  
[ncid,Data,Atts] = readnetcdf(fname,permission);%read file
  
range               = Data.Range*1000;
range_cc            = Data.Range_corrected'*1000;
z                   = Data.z_distance'*1000;
azimuth             = Data.Azimuth;
ele                 = Data.Elevation;
ele_cc              = Data.elevation_corrected';

dbz                 = double(Data.DBZ)'*double(Atts.DBZ.scale_factor)+double(Atts.DBZ.add_offset);
dbz_offset          = double(Atts.DBZ.add_offset);
dbz_fact            = double(Atts.DBZ.scale_factor);

sw                  = double(Data.SW)'*double(Atts.SW.scale_factor)+double(Atts.SW.add_offset);
sw_offset           = double(Atts.SW.add_offset);
sw_fact             = double(Atts.SW.scale_factor);

velo                = double(Data.VR)'*double(Atts.VR.scale_factor)+double(Atts.VR.add_offset);
velo_offset         = double(Atts.VR.add_offset);
velo_fact           = double(Atts.VR.scale_factor);

ldr                 = double(Data.LDR)'*double(Atts.LDR.scale_factor)+double(Atts.LDR.add_offset);
ldr_offset          = double(Atts.LDR.add_offset);
ldr_fact            = double(Atts.LDR.scale_factor);

frequency           = Data.radar_frequency;
nyquist_velo        = Data.Nyquist_Velocity;

sea_level_alt       = Data.Altitude_sea_level;
ground_level_alt    = Data.Altitude_ground_level;

radar_height_ref    = sea_level_alt+ground_level_alt;


     
%%%%%%%%%%%%% Remove extreme values %%%%%%%%%%%%%%%%%%%%%%%%%%%%%

dbz(dbz<-300)  =NaN;
velo(velo<-300)=NaN;
 
ldr(ldr<-300)  =NaN;
sw(sw<-300)    =NaN;
  

cd(path_functions)

 
%%% Locate the soundings associated to the site and date %%%%%%%
%%% of interest %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%% Read sounding data merged first %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
cd(path_mergedsounding_data)
 

soundings         = [location,'mergesonde','*c1.' date '.' '*.cdf'];
aam              = dir(soundings);
number_soundings  = length(aam);
aaa =[];

if isempty(aam)
    cd (path_sounding_data);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% If there is no merge sounde data, then look for regular soundings %%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    soundings         = [location,'sonde','*b1.' date '.' '*.cdf'];
    aaa               = dir(soundings);
    number_soundings  = length(aaa);
end


if (isempty(aam)==0) %%%% sounding present or not ?
    
[temperature,pressure,relative_hum,wind_dir,wind_speed,height,wdir,wspd,tdry,dt_sounding_scan]=read_merged_sounding(location,date,path_mergedsounding_data,data1,ele,z,radar_height_ref);

sounding_file=aam.name;

%%%%finding  5 degrees isotherm % and apply insect removal for all heights below such isotherm  %%% criteria for insects%%%%%%%%%%%%%

z_isotherm=nanmean(z(temperature<5.1&temperature>5.0==1));

elseif (isempty(aaa)==0)
   
[temperature,pressure,relative_hum,wind_dir,wind_speed,height,wdir,wspd,tdry,dt_sounding_scan,sounding_file]=read_sounding(location,date,path_sounding_data,data1,ele,z,radar_height_ref); 
 
%%%%finding  5 degrees isotherm % and apply insect removal for all heights below such isotherm  %%% criteria for insects%%%%%%%%%%%%%

z_isotherm=nanmean(z(temperature<5.1&temperature>5.0==1));
 

else
    display('there is no sounding data for this file, no doppler velocity unfolding  nor gass attenuation performed  ')
    z_isotherm=NaN;

end %%%% sounding present or not ?

 
%%%%% Ceilometer data reading for insects removal %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%% location of the ceilometer data

aaa_ceilo  = dir([path_ceilo_data location 'vceil' '*' date '*']);
ceilo_file=aaa_ceilo.name;

if (isempty(aaa_ceilo)==0)
[nc_ceilo,ceilo_data,ceilo_att] = readnetcdf([path_ceilo_data, aaa_ceilo.name],'nc_nowrite');

%% quality control
ceilo_data.first_cbh(ceilo_data.detection_status>3 & ceilo_data.detection_status==0 & ceilo_data.qc_detection_status~=0 & ceilo_data.qc_first_cbh~=0)=NaN;
ceilo_data.first_cbh(ceilo_data.first_cbh<ceilo_att.first_cbh.valid_min | ceilo_data.first_cbh< ceilo_att.first_cbh.valid_max)=NaN; 
ceilo_data.first_cbh(ceilo_data.first_cbh<-1000)=NaN;
%%%%
 

stime = datestr(double(ceilo_data.time_offset/(3600*24))+double(ceilo_data.base_time/(3600*24))+datenum('01-Jan-1970 00:00:00'),0);ctime = datevec(stime);
ceilo_time = ctime(:,4)+((ctime(:,5)+ctime(:,6)/60)/60);

ceilo_id1=find(abs((str2num(data1(58:59))+str2num(data1(60:61))/60)-ceilo_time) == nanmin(abs((str2num(data1(58:59))+str2num(data1(60:61))/60)-ceilo_time)),1,'first');

%%%%depending where the file is being taken 
if (str2num(data1(58:59))+str2num(data1(60:61))/60)< .5
    ceilo_id2=find(ceilo_time<(ceilo_time(ceilo_id1)+.5));   
    elseif (str2num(data1(58:59))+str2num(data1(60:61))/60)>23.5
        ceilo_id2=find(ceilo_time>(ceilo_time(ceilo_id1)-.5));  
    else
        ceilo_id2=find(ceilo_time>(ceilo_time(ceilo_id1)-.5)&ceilo_time<(ceilo_time(ceilo_id1)+.5));
end



cloud_base_ceilo=nanmean(ceilo_data.first_cbh(ceilo_id2)+ceilo_data.alt); %cloud_base_ceilo above sea level


%%% conservative threshold for insects LDR >= -5
  

l=(find(z<=nanmin(z_isotherm,cloud_base_ceilo-radar_height_ref))); %Applied to the lower threshod between the 5 degrees isotherm or existent cloud base.

k=find(ldr(l)>-10);%%%% -5 or -15
 

ldr(l(k))=NaN;
dbz(l(k))=NaN;
velo(l(k))=NaN;
sw(l(k))=NaN;
else
    display('there is no ceilometer data for this file, insect removal was not performed')

end
 
%%%%%%%end of insectt removal %%%%%%

cd(path_functions) 

%%%%%%%%%%%%%%%Second trip echoes checking%%%%  20>elevations>160

if strcmp(mode,'vptmo')==0
echo=find(ele<15 | ele>165);
 
[mask_echo]=sacr_masking_echo(echo,ele,range,velo);%%
  
ldr(mask_echo==1)=NaN;
dbz(mask_echo==1)=NaN;
velo(mask_echo==1)=NaN;
sw(mask_echo==1)=NaN;

end



 %%%%%%%%%%%%%% End of second trip echoes 
 
 
%%%% Correction for oxygen and water vapor reflectivity %%%%%%%%%
%%%%% attenuation %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
 
if (isempty(aaa)==0 | isempty(aam)==0) %%%%% only if sounding exits
[att_rose98]=gas_attenuation_rose98(pressure,temperature,relative_hum,frequency,range);
 
DBZ_cor=10*log10((10.^(dbz/10)).*(exp(2.*att_rose98)));  %%% correcting dbz using rosenkranz method  
  
%%%%%%%% De-aliasing %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[Up_az,Up_90,Up_az_el,number_alias,VD_unfolded_final,VD_unf_flag,percentage_VD_unf_flag]=dealiasing(path_processed_data,azimuth,range_cc,ele,ele_cc,...
                                                                                                    wind_dir,wind_speed,velo,nyquist_velo,dbz);

%%%%%%%%%%%%%%%%Second iteration  masking%%%%%%%%%


    

[mask3]=sacr_masking_iter_2(range,velo,ele,mode); %use velo  
 

ldr(mask3==0)                             = NaN;
dbz(mask3==0)                             = NaN;
velo(mask3==0)                            = NaN;
sw(mask3==0)                              = NaN;
   
DBZ_cor(mask3==0)                         = NaN;
VD_unfolded_final(mask3==0)               = NaN;
wind_speed(mask3==0)                      = NaN;
wind_dir(mask3==0)                        = NaN;
Up_az_el(mask3==0)                        = NaN;
Up_az(mask3==0)                           = NaN;
Up_90(mask3==0)                           = NaN;
     
 

%%%%


%%%%%%% Missing and extrem values data transformation to -999 %%%%
 


ldr(isnan(ldr))                             = (-999.00);
dbz(isnan(dbz))                             = (-999.00);
velo(isnan(velo))                           = (-999.00);
sw(isnan(sw))                               = (-999.00);
   
DBZ_cor(isnan(DBZ_cor))                     = (-999.00);
VD_unfolded_final(isnan(VD_unfolded_final)) = (-999.00);
wind_speed(isnan(wind_speed))               = (-999.00);
wind_dir(isnan(wind_dir))                   = (-999.00);
Up_az_el(isnan(Up_az_el))                   = (-999.00);
Up_az(isnan(Up_az))                         = (-999.00);
Up_90(isnan(Up_90))                         = (-999.00);
tdry(isnan(tdry))                           = (-999.00);
pressure(isnan(pressure))                   = (-999.00);
relative_hum(isnan(relative_hum))           = (-999.00);
wdir(isnan(wdir))                           = (-999.00);
wspd(isnan(wspd))                           = (-999.00);
height(isnan(height))                       = (-999.00);


number_alias(isnan(number_alias))           = int32(-999.00);
DBZ_cor(DBZ_cor<=-100)                      = int32((-999.00-dbz_offset)/dbz_fact);
VD_unfolded_final(VD_unfolded_final<=-100)  = int32((-999.00-velo_offset)/velo_fact);
Up_az(Up_az<=-100)                          = int32((-999.00-velo_offset)/velo_fact);
Up_90(Up_90<=-100)                          = int32((-999.00-velo_offset)/velo_fact);
Up_az_el(Up_az_el<=-100)                    = int32((-999.00-velo_offset)/velo_fact);
 

dbz(dbz<=-100)                              = int32((-999.00-dbz_offset)/dbz_fact);
velo(velo<=-100)                            = int32((-999.00-velo_offset)/velo_fact);
sw(sw<=-100)                                = int32((-999.00-sw_offset)/sw_fact);
ldr(ldr<=-100)                              = int32((-999.00-ldr_offset)/ldr_fact);
         
 

 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  
  
[stat]=put_new_var_into_netcdf(ncid,DBZ_cor,Up_90,Up_az,Up_az_el,VD_unfolded_final,wind_speed,wind_dir,number_alias,tdry,height,VD_unf_flag,percentage_VD_unf_flag,...
                                wspd,wdir,dbz,velo,sw,ldr,dbz_fact,dbz_offset,velo_fact,velo_offset,sw_fact,sw_offset,ldr_fact,ldr_offset,dt_sounding_scan,sounding_file,ceilo_file);%%%%% 
  

 else  %%%%ldr,velo,sw,dbz 
%      
netcdf.putVar(ncid,14,int32((dbz'-dbz_offset)/dbz_fact));
netcdf.putVar(ncid,15,int32((velo'-velo_offset)/velo_fact)); 
netcdf.putVar(ncid,16,int32((sw'-sw_offset)/sw_fact)); 
netcdf.putVar(ncid,22,int32((ldr'-ldr_offset)/ldr_fact)); 
%     
  end %%%%%  end of the loop Gass Attenuation and unfolding if sounding is present
%  
% 
netcdf.close(ncid);
ncid=[];   
 


end %%%% end parfor
status='completed';
display(status)
end
    
