function [temperature,pressure,relative_hum,wind_dir,wind_speed,height,wdir,wspd,tdry,dt_sounding_scan]=read_merged_sounding(location,date,path_mergedsounding_data,data1,ele,z,radar_height_ref);
%*Function* read_merged_sounding.m
% @version sacr 1.1

% *SRC_FILE*
% sacrm/read_merged_sounding.m
%
%
%  
%
%
%  

%%
%%%%%%%%%%%%%%%%%%%% DESCRIPTION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function reads sounding data 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%% INPUTS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% path_souding_data : name of the directory where the sounding data is 
%                     located [string]
% data1             : name of the processed file being used [sting]
% ele               : elevations (degrees) [number of elevations,1]
% z                 : pixels altitudes (m)
%                     [number of elevations,number of range gates]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%% OUTPUTS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% temperature        : temperature (degrees celcius) 
%                      [number of elevations,number of range gates]
% pressure           : pressure (mbars) 
%                      [number of elevations,number of range gates]
% relative_hum       : relative humidity (%)
%                      [number of elevations,number of range gates]
% wind_dir           : wind direction (degrees)
%                      [number of elevations,number of range gates]
% wind_speed         : wind speed (m/s)
%                      [number of elevations,number of range gates]
% height             : height from souonding (km)
% wdir               : wind direction from sounding (degrees)
% wspd               : wind force from sounding (m/s)
% tdry               : temperature from sounding (Celcius)
% dt_sounding_scan   : time difference between scan and sounding (s)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  This program  contains the subroutines needed for procesing raw sacr data
%
%
%  Copyright (C) 2014 McGill Clouds Research Group (http://www.clouds.mcgill.ca/)
%  Contact email address: pavlos.kollias@mcgill.ca, aleksandra.tatarevic@mcgill.ca,
%  iengjo@meteo.mcgill.ca
%
%  This source code is free software: you can redistribute it and/or modify
%  it under the terms of the GNU Lesser General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU Lesser General Public License for more details.
%
%  You should have received a copy of the GNU Lesser General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% ----------------------------------------------------------------------------
dt_sounding_scan=-999;
ZZ = size(z);
Z =size(z,2);
 
E  = length(ele);
% 
  cd (path_mergedsounding_data);
% 
% %%% Locate the merged soundings associated to the site and date %%%%%%%
% %%% of interest %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 

soundings         = [location,'mergesonde','*c1.' date '.' '*.cdf']; 
aam               = dir(soundings);
%number_soundings  = length(aam);

%for n_files=1:number_soundings
%    soundtime=str2num(aam.name(19:33));
%end

%%%%%%%% Identify the sounding the closest to the scan %%%%%%%%%%

% 
% filetime      = str2double([data1(49:56) '.' data1(58:63)]);     
% match         = abs(filetime-soundtime);
% rightsounding = match==nanmin(match);



file_sounding      = aam.name;
 
 
path_name_sounding = [path_mergedsounding_data, file_sounding];

%%%%%%%%%%%%%%%%%% Load sounding data %%%%%%%%%%%%%%%%%%%%%%%%%%


permission_sounding='NC_NOWRITE';

[nid,sonde,sonde_atts] = readnetcdf(file_sounding,permission_sounding);

netcdf.close(nid);
% 
sonde.wdir(sonde.wdir>=0 & sonde.wdir<=90)=90-sonde.wdir(sonde.wdir>=0 & sonde.wdir<=90);
  
sonde.wdir(sonde.wdir>90 & sonde.wdir<=360)=360-(sonde.wdir(sonde.wdir>90 & sonde.wdir<=360)-90);
 
%%%%%%%%% Quality Control %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

sonde.temp(sonde.temp<sonde_atts.temp.valid_min  | sonde.temp>sonde_atts.temp.valid_max)=NaN;
sonde.wspd(sonde.wspd<sonde_atts.wspd.valid_min  | sonde.wspd>sonde_atts.wspd.valid_max)=NaN;
sonde.wdir(sonde.wdir<sonde_atts.wdir.valid_min  | sonde.wdir>sonde_atts.wdir.valid_max)=NaN;
sonde.bar_pres(sonde.bar_pres<sonde_atts.bar_pres.valid_min  | sonde.bar_pres>sonde_atts.bar_pres.valid_max)=NaN;
sonde.rh(sonde.rh<sonde_atts.rh.valid_min  | sonde.rh>sonde_atts.rh.valid_max)=NaN;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%% Clean missing data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

sonde.wdir(sonde.wdir<=-9000)=NaN;
sonde.wspd(sonde.wspd<=-9000)=NaN;
sonde.temp(sonde.temp<=-9000)=NaN;
sonde.bar_pres(sonde.bar_pres<=-9000)=NaN;
sonde.rh(sonde.rh<=-9000)=NaN;
 
%%%%%%%%% Convert sounding heigth to meters above ground %%%%%%%

 
sonde.height=sonde.height*1000-radar_height_ref; 

%%%%%MAtching time of file to time of profile.

data1_time=(str2num(data1(58:59))*3600)+(str2num(data1(60:61))*60)+str2num(data1(62:63));%converts scan time to seconds from 00:00:00
 
time_index =round(nanmean(find((abs(data1_time-sonde.time)) == min(abs(data1_time-sonde.time))))); % finds the closest vertical profile to the scan time.

%%%%%%% Match scanning heigths(z) to sounding heigths , assuming fair quality in sounding heights%%%%%%%%%
height_index=NaN(E,Z);
 
for e=1:E
    for j=1:Z
    
        heigth_index(e,j) = round(nanmean(find((abs(z(e,j)-sonde.height)) == min(abs(z(e,j)-sonde.height)))));
 
    end
end
 
temperature  = NaN(ZZ);
pressure     = NaN(ZZ);
wind_dir     = NaN(ZZ);
wind_speed   = NaN(ZZ);
relative_hum = NaN(ZZ);
 

for e=1:E

temperature(e,:)  = sonde.temp(heigth_index(e,:),time_index);
pressure(e,:)     = 10*sonde.bar_pres(heigth_index(e,:),time_index);
wind_dir(e,:)     = sonde.wdir(heigth_index(e,:),time_index);
relative_hum(e,:) = sonde.rh(heigth_index(e,:),time_index);
wind_speed(e,:)   = sonde.wspd(heigth_index(e,:),time_index);

end

%%%%%%%%%% Remove extremes values %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
temperature(temperature<=-80)=NaN;
relative_hum(isnan(temperature))=NaN;
pressure(isnan(temperature))=NaN;
wind_dir(isnan(temperature))=NaN;
wind_speed(isnan(temperature))=NaN;


%%%%%%%%%%%%%%%%%%%%

height = sonde.height*1000-radar_height_ref;
wdir=sonde.wdir(:,time_index);
wspd=sonde.wspd(:,time_index);
tdry=sonde.temp(:,time_index);
dt_sounding_scan=abs(data1_time-sonde.time(time_index));

end % END function