function[status]=read_raw_data_int(path_noise_clear_sky,path_functions,path_raw_data,path_processed_data,radar,location,date,mode)

%*Function* read_raw_data_int.m
% @version sacr 1.1

% *SRC_FILE*
% sacrm/read_raw_data_int.m
% changes: new correction for the indeces. This correction will be taken
% away once ARM ingested data is corrected.
%   

%%%%%%%%%%%%%%%%%%%% DESCRIPTION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function reads raw data and separates each scans of each file of the
% chosen radar, date, location and mode. It creates an azimuth and time 
% variable . 

% This function calls: scans_correcting function
% This function calls: sacr_masking function
% This function calls: write_first_level_processing_netcdf_int function
% This function calls: curvature_correction function

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%% INPUTS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% path_noise_clear_sky :name of the directory where the .mat file 
%                       containing the noise information for clear sky is 
%                       located [string]
% path_functions       : name of the directory where where the functions 
%                        are stored [string]
% path_raw_data        : name of the directory where the raw data is 
%                        located [string]
% radar                : instrument name [string]
% location             : site [string]
% date                 : date in format yyyymmdd [string]
% mode                 : scan strategy [string]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  This program  contains the subroutines needed for procesing raw sacr data
%
%
%  Copyright (C) 2014 McGill Clouds Research Group (http://www.clouds.mcgill.ca/)
%  Contact email address: pavlos.kollias@mcgill.ca, aleksandra.tatarevic@mcgill.ca,
%  iengjo@meteo.mcgill.ca
%
%  This source code is free software: you can redistribute it and/or modify
%  it under the terms of the GNU Lesser General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU Lesser General Public License for more details.
%
%  You should have received a copy of the GNU Lesser General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% ----------------------------------------------------------------------------




%loading clear sky information to be used 
%during minimal signal detection mask  %%%%%%

%%% if the climatological file doesn't exist, it loads the generic noise
%%% file.Only works for cwrhi,hsrhi, awrhi,blrhi.
cd(path_noise_clear_sky)     
 
noise=dir([lower(location),'_noise_clear_sky_',lower(radar) '.mat']);

if (isempty(noise)==0)

noi=load([lower(location),'_noise_clear_sky_',lower(radar) '.mat'])  ;
mean_noise= noi.mean_noise; 
std_noise=noi.std_noise; noi=[];
else
    load noise_generic.mat;
end
    

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%looking for the raw data%%%%%%

cd (path_raw_data); 
aaa       = dir(['*' date '*.nc']); 
num_files = length(aaa);



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% Loop through the files of this date %%%%%%%%%%%%%%%%%%%%%%%%%%


for file = 1:num_files
    
warning off;

 
    if file < 10
       set = ['00' num2str(file)];
    elseif file >= 10 && file < 100
       set = ['0' num2str(file)];
    else
       set = num2str(file);
    end
 

%%%%%% Read data ONLY%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
permission='NC_NOWRITE';
data_raw = [aaa(file).name] ;fname=strcat([path_raw_data,data_raw]);
 
[nc,Data,Atts] = readnetcdf(fname,permission); %reads netcdf file from arm archive.
 
base_time           = Data.base_time; 
offset_time         = Data.time_offset;
time_s              = double(base_time)+double(offset_time); 
range               = Data.range;
azimuth             = Data.azimuth;
elevation           = Data.elevation;

DBZ                 = double(Data.reflectivity)*double(Atts.reflectivity.scale_factor)+double(Atts.reflectivity.add_offset);
dbz_offset          = double(Atts.reflectivity.add_offset);
dbz_fact            = double(Atts.reflectivity.scale_factor);


VELO                 = (double(Data.mean_doppler_velocity)*double(Atts.mean_doppler_velocity.scale_factor)+double(Atts.mean_doppler_velocity.add_offset));
velo_offset          = double(Atts.mean_doppler_velocity.add_offset);
velo_fact            = double(Atts.mean_doppler_velocity.scale_factor);

 
SNR                 = double(Data.snr)*double(Atts.snr.scale_factor)+double(Atts.snr.add_offset);
snr_offset          = double(Atts.snr.add_offset);
snr_fact            = double(Atts.snr.scale_factor);



LDR                 = double(Data.linear_depolarization_ratio)*double(Atts.linear_depolarization_ratio.scale_factor)+double(Atts.linear_depolarization_ratio.add_offset);
ldr_offset          = double(Atts.linear_depolarization_ratio.add_offset);
ldr_fact            = double(Atts.linear_depolarization_ratio.scale_factor);


WIDTH              = double(Data.spectral_width)*double(Atts.spectral_width.scale_factor)+double(Atts.spectral_width.add_offset);
sw_offset          = double(Atts.spectral_width.add_offset);
sw_fact            = double(Atts.spectral_width.scale_factor);


%start_c1             = Data.sweep_start_ray_index+1;  Index are not
                                                       %correct as  
                                                       %May 28,2014
%end_c1               = Data.sweep_end_ray_index+1;

frequency           = Data.frequency;
nyquist_velo        = Data.nyquist_velocity(1);
latitude            = Data.lat;
longitude           = Data.lon;
altitude_sea_level  = Data.altitude;
altitude_ground_level=Data.altitude_agl;
bw                   =Data.radar_beam_width_h;
  
netcdf.close(nc);


Data=[];Atts=[]; 


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% For arm data North is zero degree. For gridding purpose ,East is
 


  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
   
%%%%% Temporary patch to fix wrong index in the HSRHI mode     %%%%%
%%%%% Once the index bug is fixed in the ingest, please, remove %%%%
%%%%% this block 
cd (path_functions)
[start_c,end_c]=index_fix(elevation,azimuth,mode);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


 

   
    
 
%%%%

%%%zero degrees (mathematical coordinates). It also gets rid of spurious
%%%values of elevation

     
azimuth( (azimuth >=0  & azimuth<=90))=90-azimuth( (azimuth >=0  & azimuth<=90)); 
  
azimuth( (azimuth >90 & azimuth<=360))=360-(azimuth((azimuth >90 & azimuth<=360))-90);

elevation(elevation<0)=0;
  
 


 %%%% Loop through the scans of this file %%%%%%%%%%%%%%%%%%%%%%%%%

  
parfor scan=1:length(end_c)  %%% this is parallel loop,   use max(numb_scan) if indeces are corrected in the ingest
    
%%%%% Format block name %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

 display(scan) %displays scan number.

%%%%%%%%%%%%
    if scan < 10
       block = ['00' num2str(scan)];
    elseif scan >= 10 && scan < 100
       block = ['0' num2str(scan)];
    else
       block = num2str(scan);
    end
%%%%%%%%%%%%

%%%% Extract the data for the block %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
ele_raw        = elevation(start_c(scan):end_c(scan));
time_raw       = time_s(start_c(scan):end_c(scan));
dbz_raw        = DBZ(:,(start_c(scan):end_c(scan)));
velo_raw       = VELO(:,(start_c(scan):end_c(scan)));
sw_raw         = WIDTH(:,(start_c(scan):end_c(scan)));
ldr_raw        = LDR(:,(start_c(scan):end_c(scan)));
snr_raw        = SNR(:,(start_c(scan):end_c(scan)));
azimuth_raw    = azimuth(start_c(scan):end_c(scan));
 
%%%%%%% Range correction used later for masking%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
dbz_rc  = DBZ(:,(start_c(scan):end_c(scan)))-repmat(20*log10(range/1000),1,length(ele_raw)); 
 
if (isempty(ele_raw)==0 &&  sum(~isnan(ele_raw))>90)          % Check if scan isnt empty or corrupt

%%%% Fix double scans and elevations %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% Note: Only if not vertically pointing %%%%%%%
  
cd(path_functions) 

if strcmp(mode,'vptmo')~=1  && strcmp(mode,'ppimo')~=1     % Check if not vertically pointing
    [dbz_ec,ldr_ec,velo_ec,sw_ec,dbz_rc_ec,ele_ec,time_ec,azimuth_ec,snr_ec] = elevation_correction(ele_raw,dbz_raw,velo_raw,sw_raw,dbz_rc,ldr_raw,time_raw,snr_raw,azimuth_raw,bw);
else
    dbz_ec = dbz_raw; velo_ec = velo_raw; sw_ec = sw_raw; dbz_rc_ec = dbz_rc; ldr_ec=ldr_raw; ele_ec = ele_raw; time_ec = time_raw; azimuth_ec = azimuth_raw;snr_ec=snr_raw;
end
 
%%%%%%%%                                           %%%%%%%%
%%%%%%%% Correction for the curvature of the earth %%%%%%%% 
%%%%%%%%                                           %%%%%%%% 
 
[z,x,ele_cc,range_cc]=curvature_correction(range,ele_ec);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



    if strcmp(mode,'ppimo')~=1    %it creates a fixed azimuth_value for modes different to ppis%

        azimuth_one_value                = round((azimuth_ec(round(length(azimuth_ec)/2))));
        azimuth_string                   = num2str(azimuth_one_value);

%%%%% Format azimuth name %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

        if (length(azimuth_string)==1) 
           azimuth_string = ['00' azimuth_string];
        elseif (length(azimuth_string)==2)
           azimuth_string = ['0' azimuth_string];
        end

    else %ppi mode  just a little trick to keep every value in place. Azimuth value will be the elevation of the ppi scan

        azimuth_one_value                = round((ele_ec(round(length(ele_ec)/2))));    
        azimuth_string                   = num2str(azimuth_one_value);

%%%%% Format azimuth name %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

        if (length(azimuth_string)==1) 
            azimuth_string = ['00' azimuth_string];
        elseif (length(azimuth_string)==2)
            azimuth_string = ['0' azimuth_string];
    
        end
    end
                
%%%%% Format time name %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

time_half_way_scan = time_ec(round(length(time_ec)/2));
stimename = datestr(time_half_way_scan/(3600*24)+datenum('01-Jan-1970 00:00:00'),0);
ctime = datestr(time_ec/(3600*24)+datenum('01-Jan-1970 00:00:00'),0);
radar_t=str2num(ctime(:,13:14))+((str2num(ctime(:,16:17)))+(str2num(ctime(:,19:20))/60))/60;


                
hh=stimename(13:14); mmm=stimename(16:17); ss=stimename(19:20);
 
%%%%%%%%% Mask using minimum dectatable signal %%%%%%%%%%%%%%%%%%%%%%

[mask2]= sacr_masking_iter(range,dbz_rc_ec,ele_ec,mean_noise,std_noise,mode);  
  
 %%%%%%%%%%%%%%%%%%
 
 
bad_data=(mask2 == 0);

dbz_ec(bad_data)                            = int32(-999);
velo_ec(bad_data)                           = int32(-999);
sw_ec(bad_data)                             = int32(-999);
ldr_ec(bad_data)                            = int32(-999);
%snr_ec(bad_data)                          = int32(-999);  
%snr is left as is to compare masked data to raw data.  
 

%%%%%%% Missing data transformation to -999 %%%%%%%%%%%%%%%%%%%%%%%%%

dbz_ec(isnan(dbz_ec))                     = int32(-999);
velo_ec(isnan(velo_ec))                   = int32(-999);
sw_ec(isnan(sw_ec))                       = int32(-999);
ldr_ec(isnan(ldr_ec))                     = int32(-999);
dbz_rc_ec(isnan(dbz_rc_ec))               = int32(-999);
snr_ec(isnan(snr_ec))                     = int32(-999);
ele_cc(isnan(ele_cc))                     = int32(-999);
range_cc(isnan(range_cc))                 = int32(-999);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
%%%%Creating netcdf file with individual scans%% This is used later for all
%%%%other corrections.
 
[ncd] = write_first_level_processing_netcdf_int(data_raw,path_processed_data,radar,mode,location,date,hh,mmm,ss,set,block,azimuth_string,azimuth_ec,azimuth_one_value,range,range_cc,time_half_way_scan,time_ec,radar_t,nyquist_velo,frequency,latitude,longitude,altitude_sea_level,altitude_ground_level,ele_ec,ele_cc,dbz_ec,dbz_rc_ec,velo_ec,sw_ec,snr_ec,ldr_ec,dbz_fact,velo_fact,sw_fact,snr_fact,ldr_fact,dbz_offset,velo_offset,sw_offset,snr_offset,ldr_offset,x,z);
 
%%%%%%%%%%%%%
%%%%%%%%%%%%%
%%%%%%%%%%%%%
dbz_ec=[]; velo_ec=[]; sw_ec=[]; ldr_ec=[]; dbz_rc_ec=[]; ele_ec=[]; snr_ec=[]; 
dbz_raw=[]; velo_raw=[]; sw_raw=[]; ldr_raw=[]; dbz_raw=[]; ele_raw=[]; 
dbz_rc=[]; dummy=[]; azimuth_one_value=[]; azimuth_string=[]; stimename=[]; 
hh=[]; mmm=[]; ss=[]; mask2= []; bad_data= []; dummy=[];ele_cc=[];range_cc=[];
%%%%%%%%%%%%%
%%%%%%%%%%%%%
%%%%%%%%%%%%%

end %  
end %  

cd ([path_raw_data]); 
dbz_fact=[];velo_fact=[];sw_fact=[];snr_fact=[];,ldr_fact=[];dbz_offset=[];velo_offset=[];sw_offset=[];snr_offset=[];,ldr_offset=[];DBZ=[];VELO=[];SNR=[];LDR=[]; WIDTH=[];
end % END parfor file = 1:num_files

aaa=[]; num_files=[]; 

status='completed'
end % END function
