function [mask_echo]=sacr_masking_echo(echo,ele,range,velo)

%*Function* sacr_masking_echo.m
% @version sacr 1.1

% *SRC_FILE*
% sacrm/sacr_masking_iter_echo.m

%%%%%%%%%%%%%%%%%%%%%%%% DESCRIPTION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
% This function removes second trip echoes%%%%
%Best case scenario: Random doppler velocities in those second trip
%echoes
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%% INPUTS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% ele            : elevation angle (degrees)
% velo           : doppler velocity (m/s)
 
% range          : range   (m)
% echo           : beams analyzed for second trip echoes.

%%%%%%%%%%%%%%%%%%%%%%%% OUTPUTS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% mask_echo          : location of the pixels containing "second trip echoes"
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
%  This program  contains the subroutines needed for procesing raw sacr data
%
%
%  Copyright (C) 2014 McGill Clouds Research Group (http://www.clouds.mcgill.ca/)
%  Contact email address: pavlos.kollias@mcgill.ca, aleksandra.tatarevic@mcgill.ca,
%  iengjo@meteo.mcgill.ca
%
%  This source code is free software: you can redistribute it and/or modify
%  it under the terms of the GNU Lesser General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU Lesser General Public License for more details.
%
%  You should have received a copy of the GNU Lesser General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% ----------------------------------------------------------------------------

 

%%%%%% Calculate variables size %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ibox1=1;
E = length(echo);
R = length(range);

%% This mask   used the standard deviation of the values within a 3x3 box as a measure of incoherence of the returned signal.
  
  
mask_echo1 = zeros(size(velo));  

 for r=2:R;    
    
    j1=nanmin(r+1-ibox1,ibox1);j2=abs(nanmax(r-size(velo,2),-ibox1));
    
    for e=2:E;
         
        i1=nanmin(echo(e)+1-ibox1,ibox1);i2=abs(nanmax(echo(e)-size(velo,1),-ibox1));
                        
            if (nanstd(reshape(velo(echo(e)-i1:echo(e)+i2,r-j1:r+j2),1,numel(velo(echo(e)-i1:echo(e)+i2,r-j1:r+j2))))>1.5) 
               mask_echo1(echo(e),r) = 1;
           
            end
     end
   
 end
 
 %% This mask is used when there are layers of shear which might be confused for uncoherent signals.

 
  ibox1=2;
  mask_echo=mask_echo1;
    
    
for r=3:size(mask_echo1,2)-3;    
    
    j1=2;j2=2;
    
    for e=1:size(mask_echo1,1);
         if (mask_echo1(e,r))==1  
                        
            if ((sum((reshape(mask_echo1(e,r-j1:r+j2),1,numel(mask_echo1(e,r-j1:r+j2)))))<5)) 
                mask_echo(e,r) = 0; 
            end
        
         end
     end
   
end
    
  
 end
