function [mask2]=sacr_masking_iter(range,dbz_rc_ec,ele_ec,mean_noise,std_noise,mode)
 
%*Function* sacr_masking_iter.m
% @version sacr 1.1

% *SRC_FILE*
% sacrm/sacr_masking_iter.m
%
%
%  
%
%
%   
%%%%%%%%%%%%%%%%%%%%%%%% DESCRIPTION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
% This functions identifies the pixels which have a signal smaller than the
% ambiant noise and thus contains a signal that we can't trust and should
% ignore.

% This function calls: estimatenoise function
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%% INPUTS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
% ele_ec         : corrected elevation angle from raw data (degrees)
% dbz_rc_ec      : reflectivity from raw data corrected for range (dBZ)
% mean_noise     : mean noise from clear sky days at the location (dB)
% std_noise      : standard deviation of the above
% mode           : scanning mode

%%%%%%%%%%%%%%%%%%%%%%%% OUTPUTS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% mask2          : location of the pixels containing "bad data"
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%  This program  contains the subroutines needed for procesing raw sacr data
%
%
%  Copyright (C) 2014 McGill Clouds Research Group (http://www.clouds.mcgill.ca/)
%  Contact email address: pavlos.kollias@mcgill.ca, aleksandra.tatarevic@mcgill.ca,
%  iengjo@meteo.mcgill.ca
%
%  This source code is free software: you can redistribute it and/or modify
%  it under the terms of the GNU Lesser General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU Lesser General Public License for more details.
%
%  You should have received a copy of the GNU Lesser General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% ----------------------------------------------------------------------------

%%%%%% Calculate variables size %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ibox=2;
E = length(ele_ec);
R = length(range); 

%%%%% Mean noise calculation for each elevation %%%%%%%%%%% 

noise_data(1:E)=-100; % noise floor in case snr has missing values.

if strcmp(mode,'ppimo')==0
        for e2 = 1:E;

             if (sum(isnan(dbz_rc_ec(:,e2)))~= E)
          
                  noise_data(e2)=10*log10(estimatenoise(10.^(dbz_rc_ec(:,e2)/10) , R , 1));
      
      
             end
        end 
 noise_clear_std_int  = interp1(1:179,std_noise,ele_ec);
 noise_clear_int      = interp1(1:179,mean_noise,ele_ec);
 noise_clear_int_adjusted(1:E)=-100;noise_data_clean(1:E)=-100;
 
  else
        for r  = 1:R;

            if (sum(isnan(dbz_rc_ec(r,:)))~= R)
        
                 noise_data(r)=10*log10(estimatenoise(10.^(dbz_rc_ec(r,:)/10) , E , 1));
            end
        end 
 noise_clear_std_int  = interp1(1:179,std_noise,ele_ec); 
 
end
  
   
%%%%% Averaging of clear sky noise to data elevations %%%%%%%%%%%%%%%


%%% Ajust the clear sky noise 80-100 degrees elevation to the data noise 
%%% 80-100 degree elevation since these elevations are the ones we have the
%%% most confidence in to find the noise cause they are the elevations
%%% where there is the most clear sky exposed
%%% It is adapted accordingly in other modes

if strcmp(mode,'cwrhi')||strcmp(mode,'hsrhi') || strcmp(mode,'awrhi')
    center = find(abs(80-ele_ec)<0.2, 1 )  : find(abs(100-ele_ec)<0.2, 1 );
elseif strcmp(mode,'blrhi')
    center = find(abs(75-ele_ec)<0.2, 1 )  : find(abs(nanmax(ele_ec)-ele_ec)<0.2, 1 );  
elseif  strcmp(mode,'vptmo')
    center =  round((length(ele_ec)/2)-(length(ele_ec)/4)):1:round((length(ele_ec)/2)+(length(ele_ec)/4));
end


%%%% Criteria for choosing between data noise of clear sky noise %%%%

if strcmp(mode,'ppimo')==0 
    for e=1:E
        noise_clear_int_adjusted(e) = noise_clear_int(e)+(nanmean(noise_data(center))-nanmean(noise_clear_int(center)));
    end

        for e=1:E
            if noise_data(e) < noise_clear_int_adjusted(e)-1*noise_clear_std_int(e)' || noise_data(e) > noise_clear_int_adjusted(e)+1*noise_clear_std_int(e)'
     
               noise_data_clean(e) = noise_clear_int_adjusted(e);
    
            else 
               noise_data_clean(e) = noise_data(e);    
            end
    
        end 
else
    
    noise_data_clean=noise_data;
    noise_clear_std_int=nanmean(noise_clear_std_int);

end 
    
 
 
    
     
%%%% First level mask using noise floor %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  
mask1 = zeros(size(dbz_rc_ec));     
  
if strcmp(mode,'ppimo')==0 
  for e=1:E;
        if  (sum(isnan(dbz_rc_ec(:,e)))==E)~=1 
         
            k= dbz_rc_ec(:,e)>(noise_data_clean(e)+1*(noise_clear_std_int(e)));
            mask1(k,e) = 1; clear k;
        
        end
  end
 
else
    for r=1:R;
        if  (sum(isnan(dbz_rc_ec(r,:)))==R)~=1 
             k= dbz_rc_ec(r,:)>(noise_data_clean(r)+1*noise_clear_std_int);
             mask1(r,k) = 1; clear k;
        end
    end
    
end
 
mask2 = zeros(size(dbz_rc_ec));

% MASKING 2 %%%%% 
  
 
for e=1:E;    
    
    j1=nanmin(e+1-ibox,ibox);j2=abs(nanmax(e-E,-ibox));
    
    for r=1:R;
        
         if mask1(r,e) == 1
            i1=nanmin(r+1-ibox,ibox);i2=abs(nanmax(r-R,-ibox));
                        
                          
                if  sum(sum((mask1(r-i1:r+i2,e-j1:e+j2))))>14;
             
                     mask2(r,e) = 1;
           
                end
         end
   
     end
    
end
 
 end
