
function [ncd] = write_first_level_processing_netcdf_int(data_raw,path_processed_data,radar,mode,location,date,hh,mmm,ss,set,block,azimuth_string,azimuth_ec,azimuth_one_value,range,range_cc,time_half_way_scan,time_ec,radar_t,nyquist_velo,frequency,latitude,longitude,altitude_sea_level,altitude_ground_level,ele_ec,ele_cc,dbz_ec,dbz_rc_ec,velo_ec,sw_ec,snr_ec,ldr_ec,dbz_fact,velo_fact,sw_fact,snr_fact,ldr_fact,dbz_offset,velo_offset,sw_offset,snr_offset,ldr_offset,x,z);

% -------------------------------------------------------------------------
%*Function* write_first_level_processing_netcdf_int.m
% @version sacr 1.1

% *SRC_FILE*
% sacrm/write_first_level_processing_netcdf_int.m
% changes: This version only saves variables coming from raw data. No need
% to save empty variables. They will be added in the second stage
% processing.
%
%  
%
%
%  
%%%%%%%%%%%%%%%%%%%% DESCRIPTION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function writes netcdf files for each scan of each file
% individually. The netcdf files outputed contain variables with the
% data corrected to the elevation convention and masked.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%% INPUTS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% path_processed_data :  name of the directory where the processed_data
%                        will be stored
% radar                : instrument name
% location             : site 
% date                 : date in format YYYMMDD 
% mode                 : scan strategy 
% hh/mmm/ss            : hour/minute/second that corresponds to the middle
%                        of the scan
% set                  : file number 
% block                : scan number
% azimuth_strigh       : azimuth of the scan, one value string (degrees 
%                        from true North)                       
% azimuth_one_value    : azimuth of the scan, one number (degrees from true
%                        North)
% range                : distance from the radar (m)
% time_half_way_scan   : 
% time_ec              : 
% nyquist_velo         : nyquist velocity (m/s)
% frequency            : radar frequency (Hz)
% latitude             : latitude (degrees North)
% longitude            : longitude (degrees East)
% altitude_sea_level   : altitude above sea level (m) 
% ele                  : elevation (degrees)
% dbz                  : reflectivity (dBZ)
% velo                 : doppler velocity (m/s)
% sw                   : spectrum width (m/s)
% snr                  : signal to noise ratio
% ldr                  : linear depolarization ratio
 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%  This program  contains the subroutines needed for procesing raw sacr data
%
%
%  Copyright (C) 2014 McGill Clouds Research Group (http://www.clouds.mcgill.ca/)
%  Contact email address: pavlos.kollias@mcgill.ca, aleksandra.tatarevic@mcgill.ca,
%  iengjo@meteo.mcgill.ca
%
%  This source code is free software: you can redistribute it and/or modify
%  it under the terms of the GNU Lesser General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU Lesser General Public License for more details.
%
%  You should have received a copy of the GNU Lesser General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% ----------------------------------------------------------------------------

       
cd(path_processed_data)
 
%%%%%%%%%%%%%% Create netcdf file %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
if strcmp(mode,'ppimo')==0
ncd = netcdf.create([lower(radar),'_',mode,'_mode_set_' set '_block_' block '_azimuth_' azimuth_string '_' date '_' hh mmm ss '.nc' ],'clobber'); 
else
ncd = netcdf.create([lower(radar),'_',mode,'_mode_set_' set '_block_' block '_elevati_' azimuth_string '_' date '_' hh mmm ss '.nc' ],'clobber'); 
    
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%% Global attributes %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
%%%%%%%%%%%%% Define variables dimensions %%%%%%%%%%%%%%%%%%%%%%%%

maxCellsID   = netcdf.defDim(ncd,'maxCells',length(range));
timedimID    = netcdf.defDim(ncd,'time',length(ele_ec));
numoneID = netcdf.defDim(ncd,'numone',1);

%%%%%%%%%%%%%% Define variables %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Rangeid                    = netcdf.defVar(ncd,'Range','float',maxCellsID);
base_timeid                = netcdf.defVar(ncd,'m_time','double',numoneID);
time_offsetid              = netcdf.defVar(ncd,'scan_time','double',timedimID);
radar_timeid               = netcdf.defVar(ncd,'radar_time','double',timedimID);
Fixed_Angleid              = netcdf.defVar(ncd,'Fixed_Angle','float',numoneID);
Range_to_First_Cellid      = netcdf.defVar(ncd,'Range_to_First_Cell','float',numoneID);
freqid                     = netcdf.defVar(ncd,'radar_frequency','float',numoneID);
Nyquist_Velocityid         = netcdf.defVar(ncd,'Nyquist_Velocity','float',numoneID);
Latitudeid                 = netcdf.defVar(ncd,'Latitude','float',numoneID);
Longitudeid                = netcdf.defVar(ncd,'Longitude','float',numoneID);
Altitude_sea_levelid       = netcdf.defVar(ncd,'Altitude_sea_level','float',numoneID);
Altitude_ground_levelid    = netcdf.defVar(ncd,'Altitude_ground_level','float',numoneID);

Azimuthid                  = netcdf.defVar(ncd,'Azimuth','float',timedimID);
Elevationid                = netcdf.defVar(ncd,'Elevation','float',timedimID);
DBZid                      = netcdf.defVar(ncd,'DBZ','nc_int',[maxCellsID,timedimID]);
VRid                       = netcdf.defVar(ncd,'VR','nc_int',[maxCellsID,timedimID]);
SWid                       = netcdf.defVar(ncd,'SW','nc_int',[maxCellsID,timedimID]);
SNRid                      = netcdf.defVar(ncd,'SNR','nc_int',[maxCellsID,timedimID]);
elevation_correctedid      = netcdf.defVar(ncd,'elevation_corrected','double',[maxCellsID,timedimID]);
Range_correctedid          = netcdf.defVar(ncd,'Range_corrected','float',[maxCellsID,timedimID]);
x_distanceid               = netcdf.defVar(ncd,'x_distance','float',[maxCellsID,timedimID]);
z_distanceid               = netcdf.defVar(ncd,'z_distance','float',[maxCellsID,timedimID]);
LDRid                      = netcdf.defVar(ncd,'LDR','nc_int',[maxCellsID,timedimID]);
DBZrpid                    = netcdf.defVar(ncd,'DBZ_received_power','nc_int',[maxCellsID,timedimID]);

netcdf.endDef(ncd);  

%%%%%%%%%%% Put data in variables %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%%%%%%%%%
netcdf.putVar(ncd,Rangeid,range/1000);
netcdf.putVar(ncd,base_timeid,time_half_way_scan);
netcdf.putVar(ncd,time_offsetid,time_ec);
netcdf.putVar(ncd,radar_timeid,radar_t);
netcdf.putVar(ncd,Fixed_Angleid,azimuth_one_value);
netcdf.putVar(ncd,Range_to_First_Cellid,range(1)+(roundn((range(100)-range(99)),-2)));
netcdf.putVar(ncd,freqid,frequency/10^9);
netcdf.putVar(ncd,Nyquist_Velocityid,nyquist_velo);
netcdf.putVar(ncd,Latitudeid,latitude);
netcdf.putVar(ncd,Longitudeid,longitude)
netcdf.putVar(ncd,Altitude_sea_levelid,altitude_sea_level);
netcdf.putVar(ncd,Altitude_ground_levelid,altitude_ground_level);
netcdf.putVar(ncd,Azimuthid,azimuth_ec);
netcdf.putVar(ncd,Elevationid,ele_ec);
netcdf.putVar(ncd,DBZid,int32((dbz_ec-dbz_offset)/dbz_fact));
netcdf.putVar(ncd,VRid,int32((velo_ec-velo_offset)/velo_fact));
netcdf.putVar(ncd,SWid,int32((sw_ec-sw_offset)/sw_fact));
netcdf.putVar(ncd,SNRid,int32((snr_ec-snr_offset)/snr_fact));
netcdf.putVar(ncd,elevation_correctedid,ele_cc);
netcdf.putVar(ncd,Range_correctedid,range_cc/1000);
netcdf.putVar(ncd,x_distanceid,x/1000);
netcdf.putVar(ncd,z_distanceid,z/1000);
netcdf.putVar(ncd,LDRid,int32((ldr_ec-ldr_offset)/ldr_fact));
netcdf.putVar(ncd,DBZrpid,int32((dbz_rc_ec-dbz_offset)/dbz_fact));

%%%%%% Define variables attribute %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

netcdf.reDef(ncd)

netcdf.putAtt(ncd,netcdf.getConstant('nc_global'),'content','This file contains one scan of remotely sensed data'); 
netcdf.putAtt(ncd,netcdf.getConstant('nc_global'),'conventions',['Scanning_Remote_Sensor at ', upper(location),' site']);
netcdf.putAtt(ncd,netcdf.getConstant('nc_global'),'Instrument_Name',upper(radar));
netcdf.putAtt(ncd,netcdf.getConstant('nc_global'),'Instrument_Type','GROUND');
netcdf.putAtt(ncd,netcdf.getConstant('nc_global'),'Scan_Mode', upper(mode) ); 
netcdf.putAtt(ncd,netcdf.getConstant('nc_global'),'time_at_the_middle_of_the_scan',[date,'_',hh mmm ss]);
netcdf.putAtt(ncd,netcdf.getConstant('nc_global'),'description',['Netcdf File for the ', radar, ' radar ',mode,' mode']);

netcdf.putAtt(ncd,netcdf.getConstant('nc_global'),'input_radar_file',data_raw);
netcdf.putAtt(ncd,netcdf.getConstant('nc_global'),'input_sounding_file','NULL');
netcdf.putAtt(ncd,netcdf.getConstant('nc_global'),'input_ceilometer_file', 'NULL');

 
netcdf.putAtt(ncd,netcdf.getConstant('nc_global'),'name_of_the_model','sacrm_v1');
netcdf.putAtt(ncd,netcdf.getConstant('nc_global'),'author','http://wwww.clouds.mcgill.ca');
netcdf.putAtt(ncd,netcdf.getConstant('nc_global'),'institute', 'http://wwww.clouds.mcgill.ca');


netcdf.putAtt(ncd,0,'units','km');
netcdf.putAtt(ncd,0,'long_name','Range');
netcdf.putAtt(ncd,0,'missing_value','-999.000');

netcdf.putAtt(ncd,1,'units','seconds since 1970-0101 00:00 UTC');
netcdf.putAtt(ncd,1,'long_name','Unix Date/Time value to the middle of scan');
netcdf.putAtt(ncd,1,'missing_value','-999.000');

netcdf.putAtt(ncd,2,'units','seconds');
netcdf.putAtt(ncd,2,'long_name','Unix Date/Time value for each scan');
netcdf.putAtt(ncd,2,'missing_value','-999.000');

netcdf.putAtt(ncd,3,'units','hr');
netcdf.putAtt(ncd,3,'long_name','starting time');
netcdf.putAtt(ncd,3,'missing_value','-999.000');

netcdf.putAtt(ncd,4,'units','degrees');
netcdf.putAtt(ncd,4,'long_name','Targeted fixed angle for this scan');
netcdf.putAtt(ncd,4,'missing_value','-999.000');

netcdf.putAtt(ncd,5,'units','meters');
netcdf.putAtt(ncd,5,'long_name','Range to the center of the first cell');
netcdf.putAtt(ncd,5,'missing_value','-999.000');


netcdf.putAtt(ncd,6,'units','GigaHertz');
netcdf.putAtt(ncd,6,'long_name','Radar frequency');
netcdf.putAtt(ncd,6,'missing_value','-999.000');

netcdf.putAtt(ncd,7,'units','meters/second');
netcdf.putAtt(ncd,7,'long_name','Effective unambigous range');
netcdf.putAtt(ncd,7,'missing_value','-999.000');

netcdf.putAtt(ncd,8,'units','degrees north');
netcdf.putAtt(ncd,8,'long_name','Latitude of the instrument');
netcdf.putAtt(ncd,8,'missing_value','-999.000');

netcdf.putAtt(ncd,9,'units','degrees east');
netcdf.putAtt(ncd,9,'long_name','Longitude of the instrument');
netcdf.putAtt(ncd,9,'missing_value','-999.000');

netcdf.putAtt(ncd,10,'units','meters');
netcdf.putAtt(ncd,10,'long_name','Altitude in meters (asl) of the instrument');
netcdf.putAtt(ncd,10,'missing_value','-999.000');

netcdf.putAtt(ncd,11,'units','meters');
netcdf.putAtt(ncd,11,'long_name','Altitude in meters (agl) of the instrument');
netcdf.putAtt(ncd,11,'missing_value','-999.000');


netcdf.putAtt(ncd,12,'units','degrees');
netcdf.putAtt(ncd,12,'long_name','Degrees clockwise from true North');
netcdf.putAtt(ncd,12,'missing_value','-999.000');

netcdf.putAtt(ncd,13,'units','degrees');
netcdf.putAtt(ncd,13,'long_name','Elevation of the ray');
netcdf.putAtt(ncd,13,'missing_value','-999.000');


netcdf.putAtt(ncd,14,'units','dBZ');
netcdf.putAtt(ncd,14,'scale_factor',dbz_fact);
netcdf.putAtt(ncd,14,'add_offset',dbz_offset);
netcdf.putAtt(ncd,14,'comment', 'To unpack field, multiply values by the scale_factor attribute, then add the add_offset attribute.');
netcdf.putAtt(ncd,14,'long_name','Reflectivity factor');
netcdf.putAtt(ncd,14,'missing_value','-999.000');


netcdf.putAtt(ncd,15,'units','meters/second');
netcdf.putAtt(ncd,15,'scale_factor',velo_fact);
netcdf.putAtt(ncd,15,'add_offset',velo_offset);
netcdf.putAtt(ncd,15,'comment', 'To unpack field, multiply values by the scale_factor attribute, then add the add_offset attribute.');
netcdf.putAtt(ncd,15,'long_name','Doppler velocity');
netcdf.putAtt(ncd,15,'missing_value','-999.000');

netcdf.putAtt(ncd,16,'units','meters/second');
netcdf.putAtt(ncd,16,'scale_factor',sw_fact);
netcdf.putAtt(ncd,16,'add_offset',sw_offset);
netcdf.putAtt(ncd,16,'comment', 'To unpack field, multiply values by the scale_factor attribute, then add the add_offset attribute.');
netcdf.putAtt(ncd,16,'long_name','Spectral width');
netcdf.putAtt(ncd,16,'missing_value','-999.000');

netcdf.putAtt(ncd,17,'units','dB');
netcdf.putAtt(ncd,17,'scale_factor',snr_fact);
netcdf.putAtt(ncd,17,'add_offset',snr_offset);
netcdf.putAtt(ncd,17,'comment', 'To unpack field, multiply values by the scale_factor attribute, then add the add_offset attribute.');
netcdf.putAtt(ncd,17,'long_name','Signal to Noise Ratio');
netcdf.putAtt(ncd,17,'missing_value','-999.000');


netcdf.putAtt(ncd,18,'units','degrees');
netcdf.putAtt(ncd,18,'long_name','elevations corrected from curvature and sounding');
netcdf.putAtt(ncd,18,'missing_value','-999.000');


netcdf.putAtt(ncd,19,'units','km');
netcdf.putAtt(ncd,19,'long_name','Ranges corrected from curvature and sounding');
netcdf.putAtt(ncd,19,'missing_value','-999.000');


netcdf.putAtt(ncd,20,'units','km');
netcdf.putAtt(ncd,20,'long_name','X_distance corrected from curvature and sounding');
netcdf.putAtt(ncd,20,'missing_value','-999.000');


netcdf.putAtt(ncd,21,'units','km');
netcdf.putAtt(ncd,21,'long_name','Z_distances corrected from curvature and sounding');
netcdf.putAtt(ncd,21,'missing_value','-999.000');


netcdf.putAtt(ncd,22,'units','dB');
netcdf.putAtt(ncd,22,'scale_factor',ldr_fact);
netcdf.putAtt(ncd,22,'add_offset',ldr_offset);
netcdf.putAtt(ncd,22,'comment', 'To unpack field, multiply values by the scale_factor attribute, then add the add_offset attribute.');
netcdf.putAtt(ncd,22,'long_name','Depolarization Ratio');
netcdf.putAtt(ncd,22,'missing_value','-999.000');

 

netcdf.putAtt(ncd,23,'units','dBZ');
netcdf.putAtt(ncd,23,'scale_factor',dbz_fact);
netcdf.putAtt(ncd,23,'add_offset',dbz_offset);
netcdf.putAtt(ncd,23,'long_name','DBZ received power');
netcdf.putAtt(ncd,23,'missing_value','-999.000');

netcdf.close(ncd)
 

end % END function





